pub trait RaylibLoadableImage {
// Required method
fn get_filename(&self) -> &str;
}Expand description
Path-based image data that can be loaded into the renderer texture cache.
Required Methods
Sourcefn get_filename(&self) -> &str
fn get_filename(&self) -> &str
Filesystem path used as the cache key and passed to raylib’s texture loader.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".